@@ -33,9 +33,9 @@ with whitespaces.NO_WHITESPACE:
         Char(FIRST_IDENT_CHAR)
         + (Regex("(?<=[^ 0-9])\\-(?=[^ 0-9])") | Char(IDENT_CHAR))[...]
     )
-    ident_w_dash = Regex(ident_w_dash.__regex__()[1]) / no_dashes
+    ident_w_dash = Regex(ident_w_dash.__regex__()[1]).set_parser_name("identifier_with_dashes") / no_dashes
 
-simple_ident = Word(FIRST_IDENT_CHAR, IDENT_CHAR)
+simple_ident = Word(FIRST_IDENT_CHAR, IDENT_CHAR).set_parser_name("identifier")
 
 
 def common_parser():
@@ -306,15 +306,18 @@ def parser(literal_string, simple_ident, sqlserver=False):
             / to_kwarg
         ) | Group(expression)("params")
 
+        # https://cloud.google.com/bigquery/docs/reference/standard-sql/aggregate-function-calls
         call_function = (
             function_name("op")
             + LB
+            + Optional(flag("distinct"))
             + Optional(Group(query)("params") | delimited_list(one_param))
             + Optional(
                 (keyword("respect") | keyword("ignore"))("nulls")
                 + keyword("nulls").suppress()
             )
             + Optional(ORDER_BY + delimited_list(Group(sort_column))("orderby"))
+            + Optional(assign("limit", expression))
             + RB
         ) / to_json_call
 
