@@ -342,15 +342,92 @@ def to_json_call(tokens):
     )
 
 
-def to_interval_call(tokens):
-    # ARRANGE INTO {interval: [amount, type]} FORMAT
+def to_interval_type(tokens):
+    # ARRANGE INTO {op: params} FORMAT
+    op = tokens["op"].lower()
     params = tokens["params"]
-    if not params:
-        params = {}
-    if params.length() == 2:
-        return Call("interval", list(params), {})
+    if isinstance(params, (dict, str, int, Call)):
+        args = [params]
+    else:
+        args = list(params)
+
+    kwargs = tokens["kwargs"]
+
+    if args:
+        if not kwargs:
+            return {op: args}
+        elif isinstance(kwargs, str):
+            return {op: args, kwargs: {}}
+        else:
+            return {op: args, **kwargs}
+    else:
+        if not kwargs:
+            return op
+        elif isinstance(kwargs, str):
+            return {op: {}, kwargs: {}}
+        else:
+            return {op: {}, **kwargs}
+
+
+def to_interval_call(tokens, index, string):
+    # ARRANGE INTO {interval: [amount, type]} FORMAT
+    csv = list(tokens['csv'])
+    if csv:
+        result = Call("add", [
+            Call("interval", [v['expr'], v['type']], {})
+            for v in csv
+        ], {})
+    else:
+        type = tokens['type']
+        formatted = dict(tokens['formatted'])
+        expr = tokens["expr"]
+
+        if formatted:
+            if 'year' in formatted:
+                if len(formatted) == 1:
+                    if not type:
+                        raise ParseException(
+                            tokens['formatted'].type,
+                            tokens['formatted'].start,
+                            string,
+                            """Ambiguious value for given interal""",
+                        )
+                    return Call("interval", [formatted['year'], type], {})
+                elif 'year' not in type and 'month' in type:
+                    formatted['day'] = formatted['month']
+                    formatted['month'] = formatted['year']
+                    formatted['year'] = None
+            if 'hour' in formatted:
+                if 'hour' not in type and "minute" in type:
+                    formatted['second'] = formatted['minute']
+                    formatted['minute'] = formatted['hour']
+                    formatted['hour'] = None
+            if 'second' in formatted and 'fraction' in formatted and len(formatted) == 2:
+                if not type:
+                    raise ParseException(
+                        tokens['formatted'].type,
+                        tokens['formatted'].start,
+                        string,
+                        """Ambiguious value for given interal""",
+                    )
+                return Call("interval", [float(str(formatted['second'])+"."+str(formatted['fraction'])), type], {})
+
+            result = Call("add", [
+                Call("interval", [v, k], {})
+                for k, v in formatted.items()
+                if v is not None
+            ], {})
+        elif expr:
+            return Call("interval", [expr, type], {})
+        else:
+            # SIMPLE TYPE, NO VALUE
+            return type
+
+    # SIMPLIFY
+    if len(result.args) > 1:
+        return result
+    return result.args[0]
 
-    return Call("add", [Call("interval", p, {}) for p in _chunk(params, size=2)], {})
 
 
 def to_case_call(tokens):
